@@ -23,22 +23,22 @@ class TestDurationParserFunctions(unittest.TestCase):
         testtuples = (('P1Y2M3DT4H54M6S', {'PnY': '1', 'PnM': '2',
                                            'PnD': '3', 'TnH': '4',
                                            'TnM': '54', 'TnS': '6'}),
-                      ('P1Y2M3DT4H54M6.5S', {'PnY': '1', 'PnM': '2',
+                      ('P1Y2M3DT4H54M6,5S', {'PnY': '1', 'PnM': '2',
                                              'PnD': '3', 'TnH': '4',
                                              'TnM': '54', 'TnS': '6.5'}),
-                      ('P1Y2M3DT4H54M6,5S', {'PnY': '1', 'PnM': '2',
+                      ('P1Y2M3DT4H54M6.5S', {'PnY': '1', 'PnM': '2',
                                              'PnD': '3', 'TnH': '4',
                                              'TnM': '54', 'TnS': '6.5'}),
                       ('P1Y2M3D', {'PnY': '1', 'PnM': '2',
                                    'PnW': None, 'PnD': '3'}),
-                      ('P1Y2M3.5D', {'PnY': '1', 'PnM': '2',
-                                     'PnW': None, 'PnD': '3.5'}),
                       ('P1Y2M3,5D', {'PnY': '1', 'PnM': '2',
                                      'PnW': None, 'PnD': '3.5'}),
-                      ('PT4H54M6.5S', {'PnY': None, 'PnM': None, 'PnD': None,
-                                       'TnH': '4', 'TnM': '54', 'TnS': '6.5'}),
+                      ('P1Y2M3.5D', {'PnY': '1', 'PnM': '2',
+                                     'PnW': None, 'PnD': '3.5'}),
                       ('PT4H54M6,5S', {'PnY': None, 'PnM': None, 'PnD': None,
                                        'TnH': '4', 'TnM': '54', 'TnS': '6.5'}),
+                      ('PT4H54M6.5S', {'PnY': None, 'PnM': None, 'PnD': None,
+                                       'TnH': '4', 'TnM': '54', 'TnS': '6.5'}),
                       ('PT0.0000001S', {'PnY': None, 'PnM': None, 'PnD': None,
                                         'TnH': None, 'TnM': None,
                                         'TnS': '0.0000001'}),
@@ -47,28 +47,28 @@ class TestDurationParserFunctions(unittest.TestCase):
                                         'TnS': '2.0000048'}),
                       ('P1Y', {'PnY': '1', 'PnM': None,
                                'PnW': None, 'PnD': None}),
-                      ('P1.5Y', {'PnY': '1.5', 'PnM': None, 'PnW': None,
-                                 'PnD': None}),
                       ('P1,5Y', {'PnY': '1.5', 'PnM': None, 'PnW': None,
                                  'PnD': None}),
+                      ('P1.5Y', {'PnY': '1.5', 'PnM': None, 'PnW': None,
+                                 'PnD': None}),
                       ('P1M', {'PnY': None, 'PnM': '1', 'PnW': None,
                                'PnD': None}),
-                      ('P1.5M', {'PnY': None, 'PnM': '1.5', 'PnW': None,
-                                 'PnD':None}),
                       ('P1,5M', {'PnY': None, 'PnM': '1.5', 'PnW': None,
                                  'PnD':None}),
+                      ('P1.5M', {'PnY': None, 'PnM': '1.5', 'PnW': None,
+                                 'PnD':None}),
                       ('P1W', {'PnY': None, 'PnM': None, 'PnW': '1',
                                'PnD': None}),
-                      ('P1.5W', {'PnY': None, 'PnM': None, 'PnW': '1.5',
-                                 'PnD': None}),
                       ('P1,5W', {'PnY': None, 'PnM': None, 'PnW': '1.5',
                                  'PnD': None}),
+                      ('P1.5W', {'PnY': None, 'PnM': None, 'PnW': '1.5',
+                                 'PnD': None}),
                       ('P1D', {'PnY': None, 'PnM': None, 'PnW': None,
                                'PnD': '1'}),
-                      ('P1.5D', {'PnY': None, 'PnM': None, 'PnW': None,
-                                 'PnD': '1.5'}),
                       ('P1,5D', {'PnY': None, 'PnM': None, 'PnW': None,
                                  'PnD': '1.5'}),
+                      ('P1.5D', {'PnY': None, 'PnM': None, 'PnW': None,
+                                 'PnD': '1.5'}),
                       ('P0003-06-04T12:30:05', {'PnY': '0003', 'PnM': '06',
                                                 'PnD': '04', 'TnH': '12',
                                                 'TnM': '30', 'TnS': '05'}),
@@ -84,7 +84,7 @@ class TestDurationParserFunctions(unittest.TestCase):
                                                         '59.9999997'}))
 
         for testtuple in testtuples:
-            with mock.patch.object(aniso8601.builder.PythonTimeBuilder,
+            with mock.patch.object(aniso8601.duration.PythonTimeBuilder,
                                    'build_duration') as mockBuildDuration:
                 mockBuildDuration.return_value = testtuple[1]
 
@@ -106,19 +106,6 @@ class TestDurationParserFunctions(unittest.TestCase):
         self.assertEqual(result, expectedargs)
         mockBuilder.build_duration.assert_called_once_with(**expectedargs)
 
-    def test_parse_duration_relative(self):
-        with mock.patch.object(aniso8601.builder.RelativeTimeBuilder,
-                               'build_duration') as mockBuildDuration:
-            expectedargs = {'PnY': '1', 'PnM': '2', 'PnD': '3',
-                            'TnH': '4', 'TnM': '54', 'TnS': '6'}
-
-            mockBuildDuration.return_value = expectedargs
-
-            result = parse_duration('P1Y2M3DT4H54M6S', relative=True)
-
-            self.assertEqual(result, expectedargs)
-            mockBuildDuration.assert_called_once_with(**expectedargs)
-
     def test_parse_duration_nop(self):
         with self.assertRaises(ISOFormatError):
             #Duration must start with a P
@@ -190,45 +177,45 @@ class TestDurationParserFunctions(unittest.TestCase):
         testtuples = (('P1Y2M3DT4H54M6S', {'PnY': '1', 'PnM': '2',
                                            'PnD': '3', 'TnH': '4',
                                            'TnM': '54', 'TnS': '6'}),
-                      ('P1Y2M3DT4H54M6.5S', {'PnY': '1', 'PnM': '2',
-                                             'PnD': '3', 'TnH': '4',
-                                             'TnM': '54', 'TnS': '6.5'}),
                       ('P1Y2M3DT4H54M6,5S', {'PnY': '1', 'PnM': '2',
                                              'PnD': '3', 'TnH': '4',
                                              'TnM': '54', 'TnS': '6.5'}),
-                      ('PT4H54M6.5S', {'PnY': None, 'PnM': None, 'PnD': None,
-                                       'TnH': '4', 'TnM': '54', 'TnS': '6.5'}),
+                      ('P1Y2M3DT4H54M6.5S', {'PnY': '1', 'PnM': '2',
+                                             'PnD': '3', 'TnH': '4',
+                                             'TnM': '54', 'TnS': '6.5'}),
                       ('PT4H54M6,5S', {'PnY': None, 'PnM': None, 'PnD': None,
                                        'TnH': '4', 'TnM': '54', 'TnS': '6.5'}),
+                      ('PT4H54M6.5S', {'PnY': None, 'PnM': None, 'PnD': None,
+                                       'TnH': '4', 'TnM': '54', 'TnS': '6.5'}),
                       ('P1Y2M3D', {'PnY': '1', 'PnM': '2',
                                    'PnW': None, 'PnD': '3'}),
-                      ('P1Y2M3.5D', {'PnY': '1', 'PnM': '2',
-                                     'PnW': None, 'PnD': '3.5'}),
                       ('P1Y2M3,5D', {'PnY': '1', 'PnM': '2',
                                      'PnW': None, 'PnD': '3.5'}),
+                      ('P1Y2M3.5D', {'PnY': '1', 'PnM': '2',
+                                     'PnW': None, 'PnD': '3.5'}),
                       ('P1Y', {'PnY': '1', 'PnM': None,
                                'PnW': None, 'PnD': None}),
-                      ('P1.5Y', {'PnY': '1.5', 'PnM': None, 'PnW': None,
-                                 'PnD': None}),
                       ('P1,5Y', {'PnY': '1.5', 'PnM': None, 'PnW': None,
                                  'PnD': None}),
+                      ('P1.5Y', {'PnY': '1.5', 'PnM': None, 'PnW': None,
+                                 'PnD': None}),
                       ('P1M', {'PnY': None, 'PnM': '1', 'PnW': None,
                                'PnD': None}),
-                      ('P1.5M', {'PnY': None, 'PnM': '1.5', 'PnW': None,
-                                 'PnD':None}),
                       ('P1,5M', {'PnY': None, 'PnM': '1.5', 'PnW': None,
                                  'PnD':None}),
+                      ('P1.5M', {'PnY': None, 'PnM': '1.5', 'PnW': None,
+                                 'PnD':None}),
                       ('P1W', {'PnY': None, 'PnM': None, 'PnW': '1',
                                'PnD': None}),
-                      ('P1.5W', {'PnY': None, 'PnM': None, 'PnW': '1.5',
-                                 'PnD': None}),
                       ('P1,5W', {'PnY': None, 'PnM': None, 'PnW': '1.5',
                                  'PnD': None}),
+                      ('P1.5W', {'PnY': None, 'PnM': None, 'PnW': '1.5',
+                                 'PnD': None}),
                       ('P1D', {'PnY': None, 'PnM': None, 'PnW': None,
                                'PnD': '1'}),
-                      ('P1.5D', {'PnY': None, 'PnM': None, 'PnW': None,
-                                 'PnD': '1.5'}),
                       ('P1,5D', {'PnY': None, 'PnM': None, 'PnW': None,
+                                 'PnD': '1.5'}),
+                      ('P1.5D', {'PnY': None, 'PnM': None, 'PnW': None,
                                  'PnD': '1.5'}))
 
         for testtuple in testtuples:
@@ -306,33 +293,33 @@ class TestDurationParserFunctions(unittest.TestCase):
     def test_parse_duration_prescribed_notime(self):
         testtuples = (('P1Y2M3D', {'PnY': '1', 'PnM': '2',
                                    'PnW': None, 'PnD': '3'}),
-                      ('P1Y2M3.5D', {'PnY': '1', 'PnM': '2',
-                                     'PnW': None, 'PnD': '3.5'}),
                       ('P1Y2M3,5D', {'PnY': '1', 'PnM': '2',
                                      'PnW': None, 'PnD': '3.5'}),
+                      ('P1Y2M3.5D', {'PnY': '1', 'PnM': '2',
+                                     'PnW': None, 'PnD': '3.5'}),
                       ('P1Y', {'PnY': '1', 'PnM': None,
                                'PnW': None, 'PnD': None}),
-                      ('P1.5Y', {'PnY': '1.5', 'PnM': None, 'PnW': None,
-                                 'PnD': None}),
                       ('P1,5Y', {'PnY': '1.5', 'PnM': None, 'PnW': None,
                                  'PnD': None}),
+                      ('P1.5Y', {'PnY': '1.5', 'PnM': None, 'PnW': None,
+                                 'PnD': None}),
                       ('P1M', {'PnY': None, 'PnM': '1', 'PnW': None,
                                'PnD': None}),
-                      ('P1.5M', {'PnY': None, 'PnM': '1.5', 'PnW': None,
-                                 'PnD':None}),
                       ('P1,5M', {'PnY': None, 'PnM': '1.5', 'PnW': None,
                                  'PnD':None}),
+                      ('P1.5M', {'PnY': None, 'PnM': '1.5', 'PnW': None,
+                                 'PnD':None}),
                       ('P1W', {'PnY': None, 'PnM': None, 'PnW': '1',
                                'PnD': None}),
-                      ('P1.5W', {'PnY': None, 'PnM': None, 'PnW': '1.5',
-                                 'PnD': None}),
                       ('P1,5W', {'PnY': None, 'PnM': None, 'PnW': '1.5',
                                  'PnD': None}),
+                      ('P1.5W', {'PnY': None, 'PnM': None, 'PnW': '1.5',
+                                 'PnD': None}),
                       ('P1D', {'PnY': None, 'PnM': None, 'PnW': None,
                                'PnD': '1'}),
-                      ('P1.5D', {'PnY': None, 'PnM': None, 'PnW': None,
-                                 'PnD': '1.5'}),
                       ('P1,5D', {'PnY': None, 'PnM': None, 'PnW': None,
+                                 'PnD': '1.5'}),
+                      ('P1.5D', {'PnY': None, 'PnM': None, 'PnW': None,
                                  'PnD': '1.5'}))
 
         for testtuple in testtuples:
@@ -390,15 +377,15 @@ class TestDurationParserFunctions(unittest.TestCase):
         testtuples = (('P1Y2M3DT4H54M6S', {'PnY': '1', 'PnM': '2',
                                            'PnD': '3', 'TnH': '4',
                                            'TnM': '54', 'TnS': '6'}),
-                      ('P1Y2M3DT4H54M6.5S', {'PnY': '1', 'PnM': '2',
-                                             'PnD': '3', 'TnH': '4',
-                                             'TnM': '54', 'TnS': '6.5'}),
                       ('P1Y2M3DT4H54M6,5S', {'PnY': '1', 'PnM': '2',
                                              'PnD': '3', 'TnH': '4',
                                              'TnM': '54', 'TnS': '6.5'}),
-                      ('PT4H54M6.5S', {'PnY': None, 'PnM': None, 'PnD': None,
-                                       'TnH': '4', 'TnM': '54', 'TnS': '6.5'}),
+                      ('P1Y2M3DT4H54M6.5S', {'PnY': '1', 'PnM': '2',
+                                             'PnD': '3', 'TnH': '4',
+                                             'TnM': '54', 'TnS': '6.5'}),
                       ('PT4H54M6,5S', {'PnY': None, 'PnM': None, 'PnD': None,
+                                       'TnH': '4', 'TnM': '54', 'TnS': '6.5'}),
+                      ('PT4H54M6.5S', {'PnY': None, 'PnM': None, 'PnD': None,
                                        'TnH': '4', 'TnM': '54', 'TnS': '6.5'}))
 
         for testtuple in testtuples:
@@ -449,6 +436,9 @@ class TestDurationParserFunctions(unittest.TestCase):
         testtuples = (('P0003-06-04T12:30:05', {'PnY': '0003', 'PnM': '06',
                                                 'PnD': '04', 'TnH': '12',
                                                 'TnM': '30', 'TnS': '05'}),
+                      ('P0003-06-04T12:30:05,5', {'PnY': '0003', 'PnM': '06',
+                                                  'PnD': '04', 'TnH': '12',
+                                                  'TnM': '30', 'TnS': '05.5'}),
                       ('P0003-06-04T12:30:05.5', {'PnY': '0003', 'PnM': '06',
                                                   'PnD': '04', 'TnH': '12',
                                                   'TnM': '30', 'TnS': '05.5'}),
@@ -479,12 +469,12 @@ class TestDurationParserFunctions(unittest.TestCase):
         testtuples = (('P1Y2M3D', 'Y', '1'),
                       ('P1Y2M3D', 'M', '2'),
                       ('P1Y2M3D', 'D', '3'),
-                      ('T4H5M6.1234S', 'H', '4'),
-                      ('T4H5M6.1234S', 'M', '5'),
-                      ('T4H5M6.1234S', 'S', '6.1234'),
                       ('PT4H54M6,5S', 'H', '4'),
                       ('PT4H54M6,5S', 'M', '54'),
-                      ('PT4H54M6,5S', 'S', '6.5'))
+                      ('PT4H54M6,5S', 'S', '6.5'),
+                      ('T4H5M6.1234S', 'H', '4'),
+                      ('T4H5M6.1234S', 'M', '5'),
+                      ('T4H5M6.1234S', 'S', '6.1234'))
 
         for testtuple in testtuples:
             self.assertEqual(_parse_duration_element(testtuple[0],
